UDPipeBindings class

Constructors

UDPipeBindings(DynamicLibrary _lib)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

free(Pointer<NativeType> handle) → void
load(String modelPath) Pointer<NativeType>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(Pointer<NativeType> handle, String text) String?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

open() UDPipeBindings?