status property
Current loading state. Listen to this notifier to react to state changes.
Implementation
final ValueNotifier<UDPipeStatus> status = ValueNotifier(UDPipeStatus.idle);
Current loading state. Listen to this notifier to react to state changes.
final ValueNotifier<UDPipeStatus> status = ValueNotifier(UDPipeStatus.idle);