SepVerb class
A German separable verb detected in a sentence (e.g. aussteigen split into particle aus + verb stem steigt).
Constructors
Properties
- fullLemma → String
-
Reconstructed full lemma:
particle.toLowerCase() + verb.lemma, e.g."aus"+"steigen"→"aussteigen".final - hashCode → int
-
The hash code for this object.
no setterinherited
- particle → String
-
Detached particle (e.g.
"aus").final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verbForm → String
-
Inflected verb form found in the sentence (e.g.
"steigt").final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited